"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const express_1 = require("express");
const debug_1 = __importDefault(require("debug"));
const debug = debug_1.default("threes:api");
const styles_1 = __importDefault(require("../styles"));
const generator_1 = __importDefault(require("../generator"));
const router = express_1.Router();
exports.default = router;
const supportedMimeTypes = {
    "png": "image/png",
    "jpg": "image/jpg",
    "jpeg": "image/jpg",
    "svg": "image/svg+xml"
};
async function processStyle(req, res) {
    const start = process.hrtime.bigint();
    const { seed, style, format } = req.params;
    const mime = supportedMimeTypes[format];
    if (!mime) {
        res.status(404);
        return res.end();
    }
    const generator = generator_1.default.byName(style);
    if (generator == null) {
        res.status(404);
        return res.end();
    }
    const width = Number.parseInt(req.query["width"]);
    const height = Number.parseInt(req.query["height"]);
    const palette = req.query["palette"];
    try {
        const canvas = await generator.generate(seed, { width, height, style, format, palette });
        res.contentType(mime);
        const buffer = await canvas.toBuffer(format);
        res.send(buffer);
        const end = process.hrtime.bigint();
        const duration = (end - start) / 1000000n;
        debug(`Generated avatar seed='${seed}' style=${style} format=${format} duration=${duration}ms`);
    }
    catch (error) {
        debug(`Got an error while generating avatar seed='${seed}' style=${style} format=${format}`);
        console.error(error);
        res.status(500);
        return res.end();
    }
}
// GET endpoint for a single style and seed
router.get("/avatar/:style/:seed.:format", async (req, res) => {
    processStyle(req, res);
});
// GET endpoint for a palette
router.get("/palette/:style", (req, res) => {
    const { style } = req.params;
    const palette = styles_1.default[style] ? styles_1.default[style].palette || null : null;
    if (!palette) {
        res.status(404);
        return res.end();
    }
    res.contentType("application/json");
    res.send(JSON.stringify(palette));
});
router.get("/palettes", (_, res) => {
    const palettes = {};
    for (const [name, { palette }] of Object.entries(styles_1.default)) {
        if (palette)
            palettes[name] = palette;
    }
    res.contentType("application/json");
    res.send(JSON.stringify(palettes));
});
// GET endpoint for all available styles
router.get("/styles", (_, res) => {
    res.contentType("application/json");
    res.send(JSON.stringify(Object.keys(styles_1.default).filter(style => styles_1.default[style].generator)));
});
//# sourceMappingURL=v1.js.map