"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const skia_canvas_1 = require("skia-canvas");
const random_1 = __importDefault(require("./utils/random"));
const styles_1 = __importDefault(require("./styles"));
const MIN_WIDTH = 32;
const MIN_HEIGHT = 32;
const MAX_WIDTH = 1024;
const MAX_HEIGHT = 1024;
class Generator {
    generator;
    constructor(generator) {
        this.generator = generator;
    }
    static byName(name) {
        if (styles_1.default[name] && styles_1.default[name].generator)
            return new Generator(styles_1.default[name].generator);
        return null;
    }
    async generate(seed, options) {
        const width = Math.max(MIN_WIDTH, Math.min(MAX_WIDTH, (typeof options.width === "number" && !Number.isNaN(options.width)) ? options.width : 320));
        const height = Math.max(MIN_HEIGHT, Math.min(MAX_HEIGHT, (typeof options.height === "number" && !Number.isNaN(options.height)) ? options.height : 320));
        const paletteName = options.palette || options.style;
        const palette = styles_1.default[paletteName].palette || styles_1.default["default"].palette;
        const canvas = new skia_canvas_1.Canvas(width, height);
        const ctx = canvas.getContext("2d");
        const random = new random_1.default(seed);
        random.setPalette(palette);
        this.generator(ctx, random, options);
        return canvas;
    }
}
exports.default = Generator;
//# sourceMappingURL=generator.js.map