"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const debug_1 = __importDefault(require("debug"));
const debug = debug_1.default("threes:app");
const express_1 = __importDefault(require("express"));
const demo_1 = __importDefault(require("./demo"));
const v1_1 = __importDefault(require("./api/v1"));
const PORT = process.env["THREES_PORT"] || 3000;
// Cache images for a month by default
const CACHE_DURATION = process.env["THREES_CACHE_DURATION"] || 60 * 60 * 24 * 30;
const app = express_1.default();
if (process.env.NODE_ENV && process.env.NODE_ENV === "production") {
    app.use((_, res, next) => {
        // Remove the powered-by header in production
        res.removeHeader("X-Powered-By");
        // Set the cache duration in production
        res.set("Cache-Control", `public, max-age=${CACHE_DURATION}`);
        next();
    });
}
// CORS middleware
app.use((_, res, next) => {
    res.setHeader("Access-Control-Allow-Origin", "*");
    next();
});
// GET endpoint for a suite of avatars, not available in production
if (!process.env.NODE_ENV || process.env.NODE_ENV !== "production") {
    app.use(demo_1.default);
}
// API v1
app.use('/api/v1', v1_1.default);
app.listen(PORT);
debug(`Listening on :${PORT}`);
//# sourceMappingURL=server.js.map