"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.generator = exports.palette = void 0;
const skia_canvas_1 = require("skia-canvas");
const grid_1 = require("../utils/grid");
const COLUMNS = 5;
const ROWS = 5;
const BACKGROUND = '#F0F0F0';
// Taken from random users' GitHub profiles
exports.palette = [
    '#00A29B',
    '#F68498',
    '#F2BC4B',
    '#282149',
    '#FFB3C3',
    '#E76234',
    '#F58397',
    '#F8F9EC'
];
const generator = async (ctx, random) => {
    // Fill background
    ctx.fillStyle = BACKGROUND;
    ctx.fillRect(0, 0, ctx.canvas.width, ctx.canvas.height);
    // The margin correlates to 20px on a canvas of 320px
    const margin = Math.round(Math.min(ctx.canvas.width, ctx.canvas.height) * 0.0625);
    const canvas = drawContent(ctx.canvas.width, ctx.canvas.height, random);
    ctx.imageSmoothingEnabled = true;
    ctx.drawImage(canvas, margin, margin, ctx.canvas.width - margin * 2, ctx.canvas.height - margin * 2);
};
exports.generator = generator;
function drawContent(width, height, random) {
    // Create a canvas with content which can easily be scaled
    const canvas = new skia_canvas_1.Canvas(width, height);
    const ctx = canvas.getContext("2d");
    const foreground = random.color();
    // Fill background
    ctx.fillStyle = BACKGROUND;
    ctx.fillRect(0, 0, ctx.canvas.width, ctx.canvas.height);
    // Draw grid
    const grid = new grid_1.SquareGrid(ctx, COLUMNS, ROWS);
    for (let row = 0; row < ROWS; row++) {
        for (let column = 0; column < COLUMNS / 2; column++) {
            if (random.bool(0.75)) {
                const cell = grid.getCell(column, row);
                cell.fill(foreground);
                const mirroredCell = grid.getCell(COLUMNS - column - 1, row);
                if (mirroredCell)
                    mirroredCell.fill(foreground);
            }
        }
    }
    return canvas;
}
//# sourceMappingURL=github.js.map