"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Circle = exports.Arch = exports.Hexagon = exports.Rectangle = exports.Curve = exports.Polygon = exports.Shape = exports.Relative = void 0;
class Relative {
    percentage;
    min;
    max;
    constructor(percentage, min, max) {
        this.percentage = percentage;
        this.min = min;
        this.max = max;
    }
    calculateValue(ctx) {
        return Math.min(this.max, Math.max(this.min, Math.min(ctx.canvas.width, ctx.canvas.height) * this.percentage));
    }
}
exports.Relative = Relative;
class Shape {
    offset;
    size;
    constructor(offset, size) {
        this.offset = offset;
        this.size = size;
    }
}
exports.Shape = Shape;
class Polygon extends Shape {
    points;
    constructor(...points) {
        const min = {
            left: Number.MAX_VALUE,
            top: Number.MAX_VALUE
        };
        const max = {
            left: -Number.MAX_VALUE,
            top: -Number.MAX_VALUE
        };
        for (let i = 0; i < points.length; i++) {
            min.left = Math.min(min.left, points[i].left);
            min.top = Math.min(min.top, points[i].top);
            max.left = Math.max(max.left, points[i].left);
            max.top = Math.max(max.top, points[i].top);
        }
        super(min, { width: max.left - min.left, height: max.top - min.top });
        this.points = points;
    }
    draw(ctx) {
        ctx.lineTo(this.points[0].left, this.points[0].top);
        for (let i = 1; i < this.points.length; i++)
            ctx.lineTo(this.points[i].left, this.points[i].top);
    }
}
exports.Polygon = Polygon;
class Curve extends Polygon {
    constructor(gap, from, to, generator) {
        const points = [];
        for (let x = from; x < to; x += gap)
            points.push({ left: x, top: generator(x) });
        super(...points);
    }
}
exports.Curve = Curve;
class Rectangle extends Polygon {
    constructor(offset, size) {
        super({ left: offset.left, top: offset.top }, // Top left corner
        { left: offset.left + size.width, top: offset.top }, // Top right corner
        { left: offset.left + size.width, top: offset.top + size.height }, // Bottom right corner
        { left: offset.left, top: offset.top + size.height });
    }
}
exports.Rectangle = Rectangle;
class Hexagon extends Polygon {
    radius;
    constructor(offset, radius) {
        const width = 2 * radius;
        const height = Math.sqrt(3) * radius;
        super({ left: offset.left, top: offset.top + height / 2 }, // Left corner
        { left: offset.left + width / 4, top: offset.top }, // Top left corner
        { left: offset.left + width - width / 4, top: offset.top }, // Top right corner
        { left: offset.left + width, top: offset.top + height / 2 }, // Right corner
        { left: offset.left + width - width / 4, top: offset.top + height }, // Bottom right corner
        { left: offset.left + width / 4, top: offset.top + height });
        this.radius = radius;
    }
    get center() {
        return { left: this.offset.left + this.size.width / 2, top: this.offset.top + this.size.height / 2 };
    }
}
exports.Hexagon = Hexagon;
class Arch extends Shape {
    startPoint;
    controlPoint;
    endPoint;
    constructor(startPoint, endPoint, controlPoint) {
        super({ left: 0, top: 0 }, { width: 0, height: 0 });
        this.startPoint = startPoint;
        this.controlPoint = controlPoint;
        this.endPoint = endPoint;
    }
    draw(ctx) {
        ctx.moveTo(this.startPoint.left, this.startPoint.top);
        ctx.bezierCurveTo(this.controlPoint.left, this.controlPoint.top, this.endPoint.left, this.endPoint.top, this.endPoint.left, this.endPoint.top);
    }
}
exports.Arch = Arch;
class Circle extends Shape {
    radius;
    constructor(offset, radius) {
        super(offset, { width: 2 * radius, height: 2 * radius });
        this.radius = radius;
    }
    draw(ctx) {
        ctx.arc(this.offset.left, this.offset.top, this.radius, 0, 2 * Math.PI);
    }
}
exports.Circle = Circle;
//# sourceMappingURL=geometry.js.map