"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const seedrandom_1 = require("seedrandom");
/** Utility class for handling a random seed. */
class Random {
    random;
    palette;
    /** Create a random object using the given seed. */
    constructor(seed) {
        this.random = seedrandom_1.alea(seed);
        this.palette = null;
    }
    /** Set the palette used by the instance. */
    setPalette(palette) {
        this.palette = palette;
    }
    /** Get a random color from the current palette. */
    color() {
        if (!this.palette)
            throw new Error("No palette set");
        return this.palette[Math.floor(this.random() * this.palette.length)];
    }
    /** Get a random float. */
    float() {
        return this.random();
    }
    /** Get a random float between min (inc.) and max (excl.). */
    floatBetween(min, max) {
        return (this.random() * (max - min)) + min;
    }
    /** Get a random int between min (inc.) and max (excl.). */
    intBetween(min, max) {
        return Math.floor((this.random() * (max - min)) + min);
    }
    /** Get a random element of the given values. */
    element(...values) {
        return values[this.intBetween(0, values.length - 1)];
    }
    /** Get one or more random elements from a list of values. */
    elements(count, values) {
        return new Array(count).fill(null).map(() => this.element(...values));
    }
    /** Get one or more random non-repeating elements from a list of values. */
    combination(count, values) {
        const picked = [];
        const slice = values.slice();
        for (let i = 0; i < count && slice.length > 0; i++) {
            const index = this.intBetween(0, slice.length);
            picked.push(slice[index]);
            slice.splice(index, 1);
        }
        return picked;
    }
    /** Get a random sequence from a list of values. */
    sequence(count, values) {
        const picked = [];
        const start = this.intBetween(0, values.length);
        for (let i = 0; i < count && i < values.length; i++)
            picked.push(values[(i + start) % values.length]);
        return picked;
    }
    /** Returns true with a probability roughly following the percentile given. */
    bool(percentile = 0.5) {
        return this.float() <= percentile;
    }
}
exports.default = Random;
module.exports = Random;
//# sourceMappingURL=random.js.map